@@ -37,12 +37,21 @@
     #endif
 #endif
 
+//------------------------------------------------------------------------------
 int main()
 {
     int n = 5;
     double x[] = { 1, 2, 3, 4, 5 };
     double y[] = { 5, 4, 3, 2, 1 };
+    for (int i = 0; i < n; ++i) {
+        printf( "x[ %d ] = %.1f; y[ %d ] = %.1f\n",
+                i, x[ i ],
+                i, y[ i ] );
+    }
+
     double result = cblas_ddot( n, x, 1, y, 1 );
+    printf( "result = %.1f; should be 35.0\n", result );
+
     bool okay = (result == 35);
     printf( "%s\n", okay ? "ok" : "failed" );
     return ! okay;
