@@ -15,6 +15,7 @@ import time
 import re
 import tarfile
 import argparse
+import shutil
 
 # This relative import syntax works in both python2 and 3.
 from .ansicodes import font
@@ -621,10 +622,38 @@ def cublas_library():
     Does not actually run the resulting exe, to allow compiling with CUDA on a
     machine without GPUs.
     '''
-    libs = '-lcublas -lcudart'
+    # Find CUDA to add -I, -L, -rpath flags.
+    # CUDA_PATH is used in NVIDIA Getting Started documentation;
+    # CUDA_HOME is used in Spack CUDA package;
+    # else infer from `which nvcc`.
+    cuda_path = environ['CUDA_PATH']
+    if (not cuda_path):
+        cuda_path = environ['CUDA_HOME']
+    if (not cuda_path):
+        nvcc_path = shutil.which( 'nvcc' )
+        if (nvcc_path):
+            (bin_path, nvcc) = os.path.split( nvcc_path )
+            (cuda_path, bin_) = os.path.split( bin_path )
+
+    cxxflags = define('HAVE_CUBLAS')
+    ldflags  = ''
+    libs     = '-lcublas -lcudart'
+
+    if (cuda_path):
+        incdir = os.path.join( cuda_path, 'include' )
+        if (os.path.exists( incdir )):
+            cxxflags += ' -I' + incdir
+
+        libdir = os.path.join( cuda_path, 'lib64' )
+        if (not os.path.exists( libdir )):
+            libdir = os.path.join( cuda_path, 'lib' )
+        if (os.path.exists( libdir )):
+            ldflags += '-L' + libdir + ' -Wl,-rpath,' + libdir
+    # end
+
     print_subhead( 'CUDA and cuBLAS libraries' )
-    print_test( '    ' + libs )
-    env = {'LIBS': libs, 'CXXFLAGS': define('HAVE_CUBLAS')}
+    print_test( '    ' + cxxflags + ' ' + ldflags + ' ' + libs )
+    env = {'CXXFLAGS': cxxflags, 'LDFLAGS': ldflags, 'LIBS': libs}
     (rc, out, err) = compile_exe( 'config/cublas.cc', env )
     print_result( libs, rc )
     if (rc == 0):
@@ -640,11 +669,37 @@ def rocblas_library():
     Does not actually run the resulting exe, to allow compiling with ROCm on a
     machine without GPUs.
     '''
-    libs = '-lrocblas -lamdhip64'
+    # Find ROCm to add -I, -L, -rpath flags.
+    # ROCM_PATH is used in hipcc and Spack ROCm package;
+    # else infer from `which hipcc`.
+    rocm_path = environ['ROCM_PATH']
+    if (not rocm_path):
+        hipcc_path = shutil.which( 'hipcc' )
+        if (hipcc_path):
+            (bin_path, hipcc) = os.path.split( hipcc_path )
+            (rocm_path, bin_) = os.path.split( bin_path )
+
+    cxxflags = define('HAVE_ROCBLAS')
+    ldflags  = ''
+    libs     = '-lrocblas -lamdhip64'
+
+    if (rocm_path):
+        incdir = os.path.join( rocm_path, 'include' )
+        if (os.path.exists( incdir )):
+            cxxflags += ' -I' + incdir
+
+        # Some versions of ROCm (5.1.3) have both lib and lib64 directories;
+        # we need the lib directory.
+        libdir = os.path.join( rocm_path, 'lib' )
+        if (not os.path.exists( libdir )):
+            libdir = os.path.join( rocm_path, 'lib64' )
+        if (os.path.exists( libdir )):
+            ldflags += ' -L' + libdir + ' -Wl,-rpath,' + libdir
+    # end
+
     print_subhead( 'HIP/ROCm and rocBLAS libraries' )
-    print_test( '    ' + libs )
-    env = {'LIBS': libs,
-           'CXXFLAGS': define('HAVE_ROCBLAS')}
+    print_test( '    ' + cxxflags + ' ' + ldflags + ' ' + libs )
+    env = {'CXXFLAGS': cxxflags, 'LDFLAGS': ldflags, 'LIBS': libs}
     (rc, out, err) = compile_exe( 'config/rocblas.cc', env )
     print_result( libs, rc )
     if (rc == 0):
@@ -654,9 +709,9 @@ def rocblas_library():
 # end
 
 #-------------------------------------------------------------------------------
-def onemkl_library():
+def sycl_onemkl_library():
     '''
-    Tests for linking oneMKL library.
+    Tests for linking SYCL and oneMKL library.
     Does not actually run the resulting exe, to allow compiling on a
     machine without GPUs.
     '''
@@ -671,7 +726,7 @@ def onemkl_library():
         inc = '-I' + root + '/linux/include ' \
             + '-I' + root + '/linux/include/sycl '
     env = {'LIBS': libs,
-           'CXXFLAGS': inc + define('HAVE_ONEMKL')
+           'CXXFLAGS': inc + define('HAVE_SYCL')
            + ' -fsycl -Wno-deprecated-declarations'}
     (rc, out, err) = compile_exe( 'config/onemkl.cc', env )
     print_result( libs, rc )
@@ -689,7 +744,7 @@ def gpu_blas():
     test_auto   = re.search( r'\b(auto)\b',     gpu_backend )
     test_cuda   = re.search( r'\b(cuda)\b',     gpu_backend ) or test_auto
     test_rocm   = re.search( r'\b(hip|rocm)\b', gpu_backend ) or test_auto
-    test_onemkl = re.search( r'\b(onemkl)\b',   gpu_backend ) or test_auto
+    test_sycl   = re.search( r'\b(sycl)\b',     gpu_backend ) or test_auto
 
     #----- CUDA
     gpu_blas_found = False
@@ -714,16 +769,16 @@ def gpu_blas():
     else:
         print_msg( font.red( 'skipping HIP/ROCm search' ) )
 
-    #----- oneMKL
-    if (not gpu_blas_found and test_onemkl):
+    #----- SYCL
+    if (not gpu_blas_found and test_sycl):
         try:
-            onemkl_library()
+            sycl_onemkl_library()
             gpu_blas_found = True
         except Error as ex:
-            if (gpu_backend == 'onemkl'):
+            if (gpu_backend == 'sycl'):
                 raise ex  # fatal
     else:
-        print_msg( font.red( 'skipping oneMKL search' ) )
+        print_msg( font.red( 'skipping SYCL search' ) )
 
     if (not gpu_blas_found):
         print_warn( 'No GPU BLAS library found' )
