@@ -44,7 +44,7 @@ void dot(
     blas::internal_set_device( queue.device() );
 
     // call low-level wrapper
-    #if defined( BLAS_HAVE_ONEMKL )
+    #if defined( BLAS_HAVE_SYCL )
         sycl::queue syclq = queue.stream();
         // check how the result scalar was allocated
         auto result_ptr_type = sycl::get_pointer_type( result, syclq.get_context() );
@@ -95,7 +95,7 @@ void dotu(
     blas::internal_set_device( queue.device() );
 
     // call low-level wrapper
-    #if defined( BLAS_HAVE_ONEMKL )
+    #if defined( BLAS_HAVE_SYCL )
         sycl::queue syclq = queue.stream();
         // check how the result scalar was allocated
         auto result_ptr_type = sycl::get_pointer_type( result, syclq.get_context() );
