@@ -23,8 +23,8 @@ using testsweeper::ansi_normal;
 
 const double no_data = testsweeper::no_data_flag;
 
-const ParamType PT_Value  = ParamType::Value;
-const ParamType PT_List   = ParamType::List;
+// const ParamType PT_Value  = ParamType::Value; currently unused
+// const ParamType PT_List   = ParamType::List; currently unused
 const ParamType PT_Output = ParamType::Output;
 
 // -----------------------------------------------------------------------------
@@ -277,6 +277,7 @@ Params::Params():
 
     // mark framework parameters as used, so they will be accepted on the command line
     check();
+    ref();
     repeat();
     verbose();
     cache();
